@@ -29,13 +29,13 @@ class PythonHighlighter : public Cantor::DefaultHighlighter
 
   public:
     PythonHighlighter(QObject* parent);
-    ~PythonHighlighter();
+    ~PythonHighlighter() override;
 
   public Q_SLOTS:
     void updateHighlight();
 
   protected:
-    void highlightBlock(const QString& text);
+    void highlightBlock(const QString& text) Q_DECL_OVERRIDE;
 
   private:
      QRegExp commentStartExpression;
