@@ -30,7 +30,7 @@
 SageCompletionObject::SageCompletionObject(const QString& command, int index, SageSession* session) : Cantor::CompletionObject(session)
 {
     setLine(command, index);
-    m_expression=0;
+    m_expression=nullptr;
 }
 
 SageCompletionObject::~SageCompletionObject()
@@ -72,9 +72,9 @@ void SageCompletionObject::extractCompletionsNew()
 {
     Cantor::Result* res=m_expression->result();
     m_expression->deleteLater();
-    m_expression=0;
+    m_expression=nullptr;
 
-    if(!res||!res->type()==Cantor::TextResult::Type)
+    if(!res || !(res->type()==Cantor::TextResult::Type))
     {
         qDebug()<<"something went wrong fetching tab completion";
         return;
@@ -113,9 +113,9 @@ void SageCompletionObject::extractCompletionsLegacy()
 {
     Cantor::Result* res=m_expression->result();
     m_expression->deleteLater();
-    m_expression=0;
+    m_expression=nullptr;
 
-    if(!res||!res->type()==Cantor::TextResult::Type)
+    if(!res || !(res->type()==Cantor::TextResult::Type))
     {
         qDebug()<<"something went wrong fetching tab completion";
         return;
@@ -161,12 +161,12 @@ void SageCompletionObject::extractIdentifierType()
     if (m_expression->status() != Cantor::Expression::Done)
     {
 	m_expression->deleteLater();
-	m_expression = 0;
+	m_expression = nullptr;
         return;
     }
     Cantor::Result* result = m_expression->result();
     m_expression->deleteLater();
-    m_expression = 0;
+    m_expression = nullptr;
     if (!result)
 	return;
 
