@@ -37,8 +37,6 @@
 #include "settings.h"
 #include "defaultvariablemodel.h"
 
-#include "imageresult.h"
-
 typedef Cantor::ImageResult ScilabPlotResult;
 
 ScilabExpression::ScilabExpression( Cantor::Session* session ) : Cantor::Expression(session)
@@ -53,7 +51,6 @@ ScilabExpression::~ScilabExpression()
 
 void ScilabExpression::evaluate()
 {
-    qDebug() << "evaluating " << command();
     setStatus(Cantor::Expression::Computing);
 
     ScilabSession* scilabSession = dynamic_cast<ScilabSession*>(session());
@@ -121,7 +118,7 @@ void ScilabExpression::parsePlotFile(QString filename)
 
     qDebug() << "ScilabExpression::parsePlotFile: " << filename;
 
-    setResult(new ScilabPlotResult(filename));
+    setResult(new ScilabPlotResult(QUrl::fromLocalFile(filename)));
 
     setPlotPending(false);
 
