@@ -74,6 +74,11 @@ QString Backend::icon() const
     return d->icon;
 }
 
+QString Backend::version() const
+{
+    return QLatin1String();
+}
+
 QString Backend::url() const
 {
     return d->url;
@@ -167,18 +172,18 @@ Backend* Backend::createBackend(const QString& name)
             return b;
     }
 
-    return 0;
+    return nullptr;
 }
 
 QWidget* Backend::settingsWidget(QWidget* parent) const
 {
     Q_UNUSED(parent)
-        return 0;
+        return nullptr;
 }
 
 KConfigSkeleton* Backend::config() const
 {
-    return 0;
+    return nullptr;
 }
 
 
