@@ -41,10 +41,9 @@ using namespace Cantor;
 class Cantor::ExpressionPrivate
 {
 public:
-    ExpressionPrivate() {
-        result=0;
-        session=0;
-        isInternal=false;
+    ExpressionPrivate() : result(nullptr), status(Expression::Done), session(nullptr),
+    finishingBehavior(Expression::DoNotDelete), isInternal(false)
+    {
     }
 
     int id;
@@ -111,7 +110,7 @@ void Expression::setResult(Result* result)
 
     d->result=result;
 
-    if(result!=0)
+    if(result!=nullptr)
     {
         qDebug()<<"settting result to a type "<<result->type()<<" result";
         #ifdef WITH_EPS
@@ -142,7 +141,7 @@ void Expression::clearResult()
     if(d->result)
         delete d->result;
 
-    d->result=0;
+    d->result=nullptr;
 }
 
 void Expression::setStatus(Expression::Status status)
