@@ -31,7 +31,7 @@ class PageBreakEntry : public WorksheetEntry
 
   public:
     PageBreakEntry(Worksheet* worksheet);
-    ~PageBreakEntry();
+    ~PageBreakEntry() override;
 
     enum {Type = UserType + 3};
     int type() const Q_DECL_OVERRIDE;
