@@ -34,7 +34,7 @@
 #include <QObject>
 
 #include <QIcon>
-#include <KLocale>
+#include <KLocalizedString>
 #include <QDebug>
 
 ResultItem::ResultItem()
@@ -69,7 +69,7 @@ ResultItem* ResultItem::create(WorksheetEntry* parent, Cantor::Result* result)
             return item;
         }
     default:
-        return 0;
+        return nullptr;
     }
 }
 
