@@ -36,8 +36,8 @@ class ScriptEditorWidget : public KXmlGuiWindow
 {
   Q_OBJECT
   public:
-    explicit ScriptEditorWidget( const QString& filter, const QString& highlightingMode, QWidget* parent = 0 );
-    ~ScriptEditorWidget();
+    explicit ScriptEditorWidget( const QString& filter, const QString& highlightingMode, QWidget* parent = nullptr );
+    ~ScriptEditorWidget() override;
 
   Q_SIGNALS:
     void runScript(const QString& filename);
