@@ -67,6 +67,7 @@ Worksheet::Worksheet(Cantor::Backend* backend, QWidget* parent)
 
     m_isPrinting = false;
     m_loginDone = false;
+    m_isLoadingFromFile = false;
 
     enableHighlighting(Settings::self()->highlightDefault());
     enableCompletion(Settings::self()->completionDefault());
@@ -240,6 +241,11 @@ bool Worksheet::isEmpty()
     return !m_firstEntry;
 }
 
+bool Worksheet::isLoadingFromFile()
+{
+    return m_isLoadingFromFile;
+}
+
 void Worksheet::makeVisible(WorksheetEntry* entry)
 {
     QRectF r = entry->boundingRect();
@@ -762,6 +768,12 @@ void Worksheet::enableHighlighting(bool highlight)
     {
         if(m_highlighter)
             m_highlighter->deleteLater();
+
+        //octave highligther fetches the function names from octave -> we need to login here
+        //TODO: re-design this later - highlighting should also be possible in the absence of the actual backend
+        if (!m_loginDone && m_session->backend()->name() == QLatin1String("Octave"))
+            loginToSession();
+
         m_highlighter=session()->syntaxHighlighter(this);
         if(!m_highlighter)
             m_highlighter=new Cantor::DefaultHighlighter(this);
@@ -990,10 +1002,12 @@ void Worksheet::load(QIODevice* device)
 
     }
 
+    m_isLoadingFromFile = true;
 
     //cleanup the worksheet and all it contains
     delete m_session;
     m_session=nullptr;
+    m_loginDone = false;
 
     //file can only be loaded in a worksheet that was not eidted/modified yet (s.a. CantorShell::load())
     //in this case on the default "first entry" is available -> delete it.
@@ -1009,7 +1023,7 @@ void Worksheet::load(QIODevice* device)
 
     qDebug()<<"loading entries";
     QDomElement expressionChild = root.firstChildElement();
-    WorksheetEntry* entry;
+    WorksheetEntry* entry = nullptr;
     while (!expressionChild.isNull()) {
         QString tag = expressionChild.tagName();
         if (tag == QLatin1String("Expression"))
@@ -1031,16 +1045,14 @@ void Worksheet::load(QIODevice* device)
         }
         else if (tag == QLatin1String("Image"))
         {
-          entry = appendImageEntry();
-          entry->setContent(expressionChild, file);
+            entry = appendImageEntry();
+            entry->setContent(expressionChild, file);
         }
 
         expressionChild = expressionChild.nextSiblingElement();
     }
 
-    //login to the session, but let Qt process all the events in its pipeline
-    //first.
-    QTimer::singleShot(0, this, SLOT(loginToSession()));
+    m_isLoadingFromFile = false;
 
     //Set the Highlighting, depending on the current state
     //If the session isn't logged in, use the default
