@@ -48,11 +48,11 @@ class WorksheetEntry : public QGraphicsObject
   Q_OBJECT
   public:
     WorksheetEntry(Worksheet* worksheet);
-    virtual ~WorksheetEntry();
+    ~WorksheetEntry() override;
 
     enum {Type = UserType};
 
-    virtual int type() const;
+    int type() const Q_DECL_OVERRIDE;
 
     virtual bool isEmpty()=0;
 
@@ -64,8 +64,8 @@ class WorksheetEntry : public QGraphicsObject
     void setNext(WorksheetEntry*);
     void setPrevious(WorksheetEntry*);
 
-    QRectF boundingRect() const;
-    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0);
+    QRectF boundingRect() const Q_DECL_OVERRIDE;
+    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = nullptr) Q_DECL_OVERRIDE;
 
     virtual bool acceptRichText() = 0;
 
@@ -131,8 +131,8 @@ class WorksheetEntry : public QGraphicsObject
     // similar to recalculateSize, but the size change is animated
     void animateSizeChange();
     // animate the size change and the opacity of item
-    void fadeInItem(QGraphicsObject* item = 0, const char* slot = 0);
-    void fadeOutItem(QGraphicsObject* item = 0, const char* slot = "deleteLater()");
+    void fadeInItem(QGraphicsObject* item = nullptr, const char* slot = nullptr);
+    void fadeOutItem(QGraphicsObject* item = nullptr, const char* slot = "deleteLater()");
     void endAnimation();
 
     void showActionBar();
@@ -146,12 +146,12 @@ class WorksheetEntry : public QGraphicsObject
   protected:
     Worksheet* worksheet();
     WorksheetView* worksheetView();
-    void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
-    void keyPressEvent(QKeyEvent *event);
+    void contextMenuEvent(QGraphicsSceneContextMenuEvent *event) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
     void evaluateNext(EvaluationOption opt);
 
-    void hoverEnterEvent(QGraphicsSceneHoverEvent* event);
-    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event);
+    void hoverEnterEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
+    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event) Q_DECL_OVERRIDE;
 
     void setSize(QSizeF size);
 
